@@ -1,8 +1,4 @@
 # -*- coding: UTF-8 -*-
-import logging
-
-LOGGER = logging.getLogger(__name__)
-
 
 def get_result_key(app_code: str, task_name: str, task_id: str):
     return f'celery_result:{app_code}:{task_name}:{task_id}'
