@@ -1,16 +1,16 @@
 # -*- coding: utf-8 -*-
 import json
-import logging
 import traceback
 from threading import Thread
 from celery import Celery, exceptions
 from celery.result import AsyncResult
+from celery.utils.log import get_task_logger
 from redis import Redis
 from .common import thread_pool
 from .common.keys import get_result_key_filter, get_task_id_from_key
 from .common.utils import ref_to_obj, singleton
 
-LOGGER = logging.getLogger(__name__)
+LOGGER = get_task_logger(__name__)
 
 
 @singleton
